"""
Motivační program pro stahování informací o počasí z OpenWeather Maps.
Uživatel zadá na vstupu město, prográm stáhne předpověd počasí v XML.
Metoda parse_dokument() v něm vyhledá požadované tagy.
"""
import xml.etree.ElementTree as xtre #práce s XML
import urllib.request as pozadavek #pro práci s URL jako se streamem
import matplotlib.pyplot as plt #pro kreslení
import matplotlib.dates as datumy


def vytvor_url(mesto):
    """ Funkce vrací URL pro zadané městi pro aktualni pocasi"""
    # http://api.openweathermap.org/data/2.5/weather?q=Decin%20&mode=xml&appid=ee757f5e8b09a2d3fbe099f14cc70891
    s = "http://api.openweathermap.org/data/2.5/forecast?q={0}%20&mode=xml&units=metric&appid=ee757f5e8b09a2d3fbe099f14cc70891"
    return s.format(mesto)

def parsuj_dokument(url):
    """Procházení/vyhledávání elementů s informacemi v XML"""
    try:
        xmldata = xtre.parse(pozadavek.urlopen(url))
        data = {} # slovník s požadovanými informacemi
        for time_element in xmldata.iter('time'):
            smer_vetru = time_element.find('windDirection').get('deg')
            rychlost_vetru = time_element.find('windSpeed').get('mps')
            prumerna_teplota = time_element.find('temperature').get('value')
            data[time_element.get('from')] = (prumerna_teplota,smer_vetru,rychlost_vetru)
        return data
    except:
        print("Nelze stáhnout data z url \n {0}".format(url))

def visualisuj(data,mesto):
    """Funkce pro vykreslování dat, není třeba vysvětlovat"""
    casova_osa = [ datumy.datestr2num(t) for t in data.keys() ]  # prevod retezcu na datumy ve floatu
    prumerna_teplota = [ v[0] for k, v in data.items() ] #seznam teplot
    uhel=[ v[1] for k, v in data.items() ] #seznam stažených úhlů
    rychlost=[ v[2] for k, v in data.items() ] #seznam stažených rychlostí
    print(uhel)
    plt.grid(True)
    plt.xlabel("Čas")
    plt.ylabel("Teplota [C]")
    plt.title("Počasí v {0}".format(mesto))
    plt.gca().xaxis.set_major_formatter(datumy.DateFormatter('\n%d %m %Y'))
    plt.gca().xaxis.set_major_locator(datumy.DayLocator(interval = 1))
    plt.gca().xaxis.set_minor_formatter(datumy.DateFormatter('%H'))
    plt.gca().xaxis.set_minor_locator(datumy.HourLocator(interval = 6))


    plt.plot(casova_osa,prumerna_teplota,'b')
    plt.show()
    #vykreslení směrů větru
    for i,(x,y) in enumerate(zip(uhel,rychlost)):
        plt.polar(x, y, 'bo') #použij polární graf
        cas = datumy.num2date(casova_osa[i])
        plt.text(x,y,'{0}.{1} {2}:00'.format(cas.day,cas.month,cas.hour), horizontalalignment='center',verticalalignment='bottom')
    plt.title("Směr větru  v {0}".format(mesto))
    plt.show()


def main():
    mesto = input("Zadej mesto: ")
    url = vytvor_url(mesto)
    data = parsuj_dokument(url)
    if data != None:
        visualisuj(data, mesto)



main()
